package com.gct.aoid.config;

import com.gct.aoid.job.CalLiqDailyJobDetail;
import com.gct.aoid.job.JobDataKey;
import com.gct.aoid.job.TriggerConfigProperties;
import org.quartz.*;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.Date;

/**
 * class name: QuartzTaskConfig
 *
 * @author lloyd
 * @version 1.0
 * @since 2021/5/21 上午10:21
 */
@Configuration
@EnableConfigurationProperties(TriggerConfigProperties.class)
public class QuartzTaskConfig {

    @Autowired
    private TriggerConfigProperties triggerConfigProperties;

    @Bean
    public JobDetail jobDetail1() {
        try {
            return JobBuilder.newJob(CalLiqDailyJobDetail.class)
                    .withIdentity(triggerConfigProperties.getJt1().getJobName(), triggerConfigProperties.getJt1().getJobGroup())
                    .usingJobData(JobDataKey.JobName.getDec(), triggerConfigProperties.getJt1().getJobName())
                    .usingJobData(JobDataKey.JobGroup.getDec(), triggerConfigProperties.getJt1().getJobGroup())
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create JobDetail-1 failed:{}", e.getMessage());
            throw e;
        }
    }

    @Bean
    public Trigger trigger1() {
        try {
            SimpleScheduleBuilder scheduleBuilder = SimpleScheduleBuilder.simpleSchedule()
                    .withIntervalInSeconds(triggerConfigProperties.getJt1().getIntervalInSeconds());
            if (triggerConfigProperties.getJt1().getIsRepeatable())
                scheduleBuilder.repeatForever();
            return TriggerBuilder.newTrigger()
                    .forJob(triggerConfigProperties.getJt1().getJobName(), triggerConfigProperties.getJt1().getJobGroup())
                    .startAt(new Date(new Date().getTime() + triggerConfigProperties.getJt1().getDelayMilliseconds()))
                    .withSchedule(scheduleBuilder).build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create Trigger-1 failed:{}", e.getMessage());
            throw e;
        }
    }
}
