package com.gct.aoid.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fasterxml.jackson.databind.JsonNode;
import com.gct.aoid.entity.AoidDailyYield;
import com.gct.aoid.feignclient.BaseDataClient;
import com.gct.aoid.mapper.AoidDailyYieldMapper;
import com.gct.aoid.service.AoidDailyYieldService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author Jyx
 * @since 2021-01-28
 */
@Service
public class AoidDailyYieldServiceImpl extends ServiceImpl<AoidDailyYieldMapper, AoidDailyYield> implements AoidDailyYieldService {
    private  DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    @Autowired
    private AoidDailyYieldMapper aoidDailyYieldMapper;
    @Autowired
    BaseDataClient baseDataClient;
    @Override
    public Result getSingleHistoryYieldCurveOrChart(String wellName, String beginDate, String endDate) {
        QueryWrapper<AoidDailyYield> queryWrapper = new QueryWrapper<>();
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        LocalDateTime begin = LocalDateTime.parse((beginDate.length() == 10 ? beginDate + " 00:00:00" : beginDate), dtf);
        LocalDateTime end = LocalDateTime.parse((endDate.length() == 10 ? endDate + " 00:00:00" : endDate), dtf);
        QueryWrapper<AoidDailyYield> wrapper = queryWrapper.select(
                //日志
                "a2LiqProdDaily",
                "a2OilProdDaily",
                "a2WaterCut",
                //计算
                "liqProdDaily",
                "oilProdDaily",
                "waterCut")
                .ge("prodDate", begin)
                .le("prodDate", end)
                .eq("wellCommonName", wellName);
        List<AoidDailyYield> aoidDailyYields = aoidDailyYieldMapper.selectList(wrapper);
        return Result.ok(aoidDailyYields);
    }

    @Override
    public List<Map<String, Object>> getAoidDailyYieldInfoByWellIdAndPorDatePeriod(String wellId, String startDate) {
        startDate = startDate+" 00:00:00";
        LocalDateTime localDateTime = LocalDateTime.parse(startDate, df);
        LocalDateTime localDateTime1 = localDateTime.plusDays(1);
        String end = localDateTime1.format(df);
        QueryWrapper<AoidDailyYield> wrapper = new QueryWrapper<>();
        LambdaQueryWrapper<AoidDailyYield> queryWrapper = wrapper.lambda().eq(AoidDailyYield::getWellId, wellId).
                ge(AoidDailyYield::getProdDate, Timestamp.valueOf(LocalDateTime.parse(startDate,df))).
                le(AoidDailyYield::getProdDate,Timestamp.valueOf(LocalDateTime.parse(end,df))).orderByAsc(AoidDailyYield::getProdDate);
        List<Map<String, Object>> maps = aoidDailyYieldMapper.selectMaps(queryWrapper);
        for (Map<String, Object> map : maps) {
            String date = map.get("prod_date").toString().substring(0, 10);
            String time = map.get("prod_date").toString().substring(11, 19);
//            map.put("prod_date",date+" "+time);
            map.put("prod_date",date);
        }
        return maps;



    }
    public Page<Map<String,Object>> getAoidDailyYieldInfoByWellIdAndPorDatePeriodByPage(String wellId, String startDate,int pageSize,int pageNum){
        startDate = startDate+" 00:00:00";
        LocalDateTime localDateTime = LocalDateTime.parse(startDate, df);
        LocalDateTime localDateTime1 = localDateTime.plusDays(1);
        String end = localDateTime1.format(df);
        QueryWrapper<AoidDailyYield> wrapper = new QueryWrapper<>();
        LambdaQueryWrapper<AoidDailyYield> queryWrapper = wrapper.lambda().eq(AoidDailyYield::getWellId, wellId).
                ge(AoidDailyYield::getProdDate, Timestamp.valueOf(LocalDateTime.parse(startDate,df))).
                le(AoidDailyYield::getProdDate,Timestamp.valueOf(LocalDateTime.parse(end,df))).orderByAsc(AoidDailyYield::getProdDate);
        Page<Map<String,Object>> paramPage = new Page<>(pageNum,pageSize);
        Page<Map<String, Object>> mapPage = aoidDailyYieldMapper.selectMapsPage(paramPage, queryWrapper);
        for (Map<String, Object> map : mapPage.getRecords()) {
            String date = map.get("prod_date").toString().substring(0, 10);
            String time = map.get("prod_date").toString().substring(11, 19);
//            map.put("prod_date",date+" "+time);
            map.put("prod_date",date);
        }
        return mapPage;
    }

    @Override
    public AoidDailyYield getDefaultData() {
        AoidDailyYield aoidDailyYield = aoidDailyYieldMapper.selectOne(new QueryWrapper<AoidDailyYield>().last(" limit 1"));
        String org = baseDataClient.getOrgId(aoidDailyYield.getZyq());
        Result<List<Map<String, Object>>> result =JSONObject.parseObject(org, Result.class);
        aoidDailyYield.setJq(result.getData().get(11).get("orgId").toString());
        aoidDailyYield.setZd(result.getData().get(5).get("orgId").toString());
        return aoidDailyYield;



    }
}
