package com.gct.aoid.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.aoid.entity.AoidSinglegtYield;
import com.gct.aoid.mapper.AoidSinglegtYieldMapper;
import com.gct.aoid.service.AoidSinglegtYieldService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import com.gct.common.util.SGTUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.text.ParseException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author 王森玉
 * @since 2021-01-31
 */
@Service
public class AoidSinglegtYieldServiceImpl extends ServiceImpl<AoidSinglegtYieldMapper, AoidSinglegtYield> implements AoidSinglegtYieldService {

    private DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    @Autowired
    public AoidSinglegtYieldMapper aoidSinglegtYieldMapper;

    /**
     * 量液--功图平铺
     * @param pageNum
     * @param pageSize
     * @param jh
     * @author:王森玉
     * @return
     */

    @Override
    public Result findAoidSinglegtYieldByPages(Integer pageNum, Integer pageSize, String jh)
    {

        //分页插件
        Page<Map<String,Object>> paramPage = new Page<>(pageNum,pageSize);
        paramPage.offset();
        paramPage.addOrder(OrderItem.asc("prod_date"));
        //查询条件
        QueryWrapper<AoidSinglegtYield> queryWrapper = new QueryWrapper<>();
        QueryWrapper<AoidSinglegtYield> wapper = null;

        wapper = queryWrapper.select("well_common_name","zdjg","prod_date","liq_prod_daily","sgt","oil_prod_daily","stroke","frequence","bx","hsl")
                .eq("well_common_name",jh);

        Page<Map<String,Object>> page = aoidSinglegtYieldMapper.selectMapsPage(paramPage,wapper);

        //格式化功图数据
        List<Map<String,Object>> records = page.getRecords();
        records.forEach((map)->{
            map.put("sgt", SGTUtil.encodeToView((String)map.get("sgt")));
            map.put("prod_date",df.format(((Timestamp)map.get("prod_date")).toLocalDateTime()));
        });
        return Result.ok(page);
    }


    @Override
    public List<AoidSinglegtYield> findByJh(String jh) {

         return aoidSinglegtYieldMapper.findByJh(jh);

    }


    @Override
    public List<Map<String, Object>> getAoidSinglegtYieldInfoByWellIdAndPorDatePeriod(String wellId, String startDate) {
        startDate = startDate+" 00:00:00";
        LocalDateTime localDateTime = LocalDateTime.parse(startDate, df);
        LocalDateTime localDateTime1 = localDateTime.plusDays(1);
        String end = localDateTime1.format(df);
        QueryWrapper<AoidSinglegtYield> wrapper = new QueryWrapper<>();
        LambdaQueryWrapper<AoidSinglegtYield> queryWrapper = wrapper.lambda().eq(AoidSinglegtYield::getWellId, wellId).
                ge(AoidSinglegtYield::getProdDate,Timestamp.valueOf(LocalDateTime.parse(startDate,df))).
                le(AoidSinglegtYield::getProdDate,Timestamp.valueOf(LocalDateTime.parse(end,df))).orderByAsc(AoidSinglegtYield::getProdDate);
        List<Map<String, Object>> maps = aoidSinglegtYieldMapper.selectMaps(queryWrapper);
        for (Map<String, Object> map : maps) {
            String date = map.get("prod_date").toString().substring(0, 10);
            String time = map.get("prod_date").toString().substring(11, 19);
            List<List<Double>> bgtList = SGTUtil.encodeToUseList((String) map.get("bgt"));
            List<List<Double>> sgtList = SGTUtil.encodeToUseList((String) map.get("sgt"));
            List<List<Double>> tmp = new ArrayList<>();
            sgtList.remove(sgtList.size()-1);
            sgtList.add(sgtList.get(0));
             map.put("bgt",bgtList);
             map.put("sgt",sgtList);
             map.put("prod_date",date+" "+time);
        }
        return  maps;
    }

    @Override
    public Page<Map<String,Object>> getAoidSinglegtYieldInfoByWellIdAndPorDatePeriodAndPages(String wellId, String startDate, String endDate, int page, int size) throws ParseException {
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        QueryWrapper<AoidSinglegtYield> wrapper = new QueryWrapper<>();
        LambdaQueryWrapper<AoidSinglegtYield> queryWrapper = wrapper.lambda().eq(AoidSinglegtYield::getWellId, wellId).
                ge(AoidSinglegtYield::getProdDate,Timestamp.valueOf(LocalDateTime.parse(startDate+" 00:00:00",df))).
                le(AoidSinglegtYield::getProdDate,Timestamp.valueOf(LocalDateTime.parse(endDate+" 00:00:00",df))).orderByAsc(AoidSinglegtYield::getProdDate);
        Page<Map<String,Object>> mapPage = aoidSinglegtYieldMapper.selectMapsPage(new Page(page, size), queryWrapper);



        for (Map<String, Object> record : mapPage.getRecords()) {
            String date = record.get("prod_date").toString().substring(0, 10);
            String time = record.get("prod_date").toString().substring(11, 19);
            List<List<Double>> bgtList = SGTUtil.encodeToUseList((String) record.get("bgt"));
            List<List<Double>> sgtList = SGTUtil.encodeToUseList((String) record.get("sgt"));

            sgtList.remove(sgtList.size()-1);
            sgtList.add(sgtList.get(0));

            record.put("bgt",bgtList);
            record.put("sgt",sgtList);
            record.put("prod_date",date+" "+time);
            double yxcc = Double.valueOf(record.get("yxcc").toString());
            List<List<Double>> sgtLeft = new ArrayList<>();
            for (int i =sgtList.size()>>1;i<sgtList.size(); i++){
                double s = (double) sgtList.get(i).toArray()[0];
                if(yxcc>s){
                    sgtLeft.add(sgtList.get(i-1));
                 }
            }
            sgtLeft.add(sgtList.get(sgtList.size()-1));
            record.put("sgtLeft",sgtLeft.toString());
            record.put("sgtUp",sgtList.subList(0,sgtList.size()/2).toString());
            List<List<Double>> list = new ArrayList<>(sgtList.subList((sgtList.size() /2) - 1, sgtList.size()));
            record.put("sgtDown",list.toString());
        }
        return mapPage;
    }


}
